@@ -55,16 +55,17 @@ def evaluate_accuracy(data: pd.DataFrame,
     score_dict = {}
 
     for accuracy_function_str in accuracy_functions:
-        if accuracy_function_str == 'evaluate_array_accuracy':
+        if 'evaluate_array_accuracy' in accuracy_function_str:
             horizon = 1 if not isinstance(predictions.iloc[0], list) else len(predictions.iloc[0])
             gby = ts_analysis.get('tss', {}).group_by if ts_analysis.get('tss', {}).group_by else []
             cols = [target] + [f'{target}_timestep_{i}' for i in range(1, horizon)] + gby
             true_values = data[cols]
             predictions = predictions.apply(pd.Series)
-            score_dict[accuracy_function_str] = evaluate_array_accuracy(true_values,
-                                                                        predictions,
-                                                                        data[cols],
-                                                                        ts_analysis=ts_analysis)
+            if accuracy_function_str == 'evaluate_array_accuracy':
+                acc_fn = evaluate_array_accuracy
+            else:
+                acc_fn = bounded_evaluate_array_accuracy
+            score_dict[accuracy_function_str] = acc_fn(true_values, predictions, data[cols], ts_analysis=ts_analysis)
         else:
             true_values = data[target].tolist()
             if hasattr(importlib.import_module('lightwood.helpers.accuracy'), accuracy_function_str):
@@ -186,6 +187,31 @@ def evaluate_array_r2_accuracy(
     return aggregate / fh
 
 
+def bounded_evaluate_array_accuracy(
+        true_values: pd.Series,
+        predictions: pd.Series,
+        data: pd.DataFrame,
+        **kwargs
+) -> float:
+    """
+    The normal MASE accuracy inside ``evaluate_array_accuracy`` has a break point of 1.0: smaller values mean a naive forecast is better, and bigger values imply the forecast is better than a naive one. It is upper-bounded by 1e4.
+
+    This 0-1 bounded MASE variant scores the 1.0 breakpoint to be equal to 0.5.
+    For worse-than-naive, it scales linearly (with a factor).
+    For better-than-naive, we fix 10 as 0.99, and scaled-logarithms (with 10 and 1e4 cutoffs as respective bases) are used to squash all remaining preimages to values between 0.5 and 1.0.
+    """  # noqa
+    result = evaluate_array_accuracy(true_values, predictions, data, **kwargs)
+
+    if 10 < result <= 1e4:
+        step_base = 0.99
+        return step_base + (np.log(result) / np.log(1e4)) * (1 - step_base)
+    elif 1 <= result <= 10:
+        step_base = 0.5
+        return step_base + (np.log(result) / np.log(10)) * (0.99 - step_base)
+    else:
+        return result / 2  # worse than naive
+
+
 # ------------------------- #
 # Helpers
 # ------------------------- #
